@@ -330,8 +330,8 @@ proc ::tcl::tm::Defaults {} {
     # something other than [::list] in this namespace.
 
     # OpenBSD layout
-    add [file join [info library] modules [info tclversion]] \
-	[file join [file dirname [info library]] modules [info tclversion]]
+    add [file join [info library] modules] \
+	[file join [lindex $::tcl_pkgPath 0] modules 85]
 
     if {$tcl_platform(platform) eq "windows"} {
 	set sep ";"
